from setuptools import setup

setup(name='prob_dist_udacity',
      version='1.1',
      description='Gaussian and Binomial distributions',
      packages=['prob_dist_udacity'],
      author='Sunil Kumar Vuppala',
      author_email='sunilkumar.vuppala01@gmail.com',
      zip_safe=False)
